@@ -54,6 +54,10 @@ class XMLRequest(ABC):
     def menu_items_request(self):
         pass
 
+    @abstractclassmethod
+    def category(self):
+        pass
+
 
 class RKXMLRequest(XMLRequest):
     media_type = "text/xml"
@@ -339,3 +343,17 @@ class RKXMLRequest(XMLRequest):
                             code=item.attrib['Code'])
                         data.append(waiter_dto)
         return data
+
+    def category(self):
+        body = '<RK7Query><RK7CMD CMD="GetRefData" RefName = "CATEGLIST" IgnoreEnums="1" WithChildItems="3"' \
+            'WithMacroProp="1" OnlyActive = "1"/></RK7Query>'
+        element = []
+        response = self.send_request(body=body)
+        try:
+            parsed_element = Etree.fromstring(response.content)
+            for item in parsed_element.findall("./RK7Reference/Items/"):
+                attr_of_item_node = item.attrib
+                element.append(attr_of_item_node)
+        except Exception as error:
+            raise ParseError(f"XML parse error - {str(error)}")
+        return element
